@@ -6,7 +6,10 @@ use v5.14.2;
 
 use warnings;
 
-our $VERSION = '0.122';
+use subs qw();
+use vars qw($VERSION);
+
+$VERSION = '1.001';
 
 UNITCHECK {
 sub _running_under_docreader {
@@ -35,11 +38,11 @@ __PACKAGE__->$method(@ARGV) if defined $method;
 
 =head1 NAME
 
-Modulino::Demo - A demonstration of module ideas
+__PACKAGE__ - A demonstration of module ideas
 
 =head1 SYNOPSIS
 
-	use Modulino::Demo;
+	use __PACKAGE__;
 
 =head1 DESCRIPTION
 
@@ -157,7 +160,7 @@ sub _test_doc {
 
 This source is in Github:
 
-	https://github.com/briandfoy/modulino-demo/
+	http://github.com/briandfoy/modulino-demo/
 
 =head1 AUTHOR
 
@@ -165,9 +168,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2012-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2012-2014, brian d foy, All Rights Reserved.
 
-You may redistribute this under the terms as the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
