@@ -6,15 +6,18 @@ use v5.14.2;
 
 use warnings;
 
+use subs qw();
+use vars qw($VERSION);
+
 require Modulino::Base;
 
-our $VERSION = '0.122';
+$VERSION = '1.001';
 
 =encoding utf8
 
 =head1 NAME
 
-Modulino::Demo3 - A demonstration of modulino ideas
+Modulino::Demo - A demonstration of modulino ideas
 
 =head1 SYNOPSIS
 
@@ -133,7 +136,7 @@ sub _test_doc {
 
 This source is in Github:
 
-	https://github.com/briandfoy/modulino-demo/
+	http://github.com/briandfoy/modulino-demo/
 
 =head1 AUTHOR
 
@@ -141,9 +144,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2012-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2012-2014, brian d foy, All Rights Reserved.
 
-You may redistribute this under the terms of the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
